#
# spec file for package mt-st
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mt-st
Version:        1.7
Release:        1.9
Summary:        Utility for Controlling Magnetic Tape Drives
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Backup
URL:            https://github.com/iustin/%{name}
Source0:        https://github.com/iustin/mt-st/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/iustin/mt-st/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        stinit.def
Source3:        61-storage-tape-init.rules
Source4:        %{name}.keyring
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       mt

%description
mt-st tools contains two programs: mt and stinit, used for dealing
with Linux-specific tape-drive handling. mt program is tailored for
SCSI tape drives, but it can also be used with other Linux tape
drivers that use the same ioctls. The program stinit is meant for
initializing of SCSI tape drive modes at system startup, or when
new tape drivers are added.

%prep
%setup -q

%build
%make_build CFLAGS="%{optflags} -pipe" DEFTAPE=/dev/nst0

%install
%make_install EXEC_PREFIX=%{_prefix}
install -D -p -m 0644 %{SOURCE2} \
  %{buildroot}%{_sysconfdir}/stinit.def
install -D -p -m 0644 %{SOURCE3} \
  %{buildroot}%{_udevrulesdir}/61-storage-tape-init.rules
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mv %{buildroot}%{_sysconfdir}/bash_completion.d/%{name} %{buildroot}%{_datadir}/bash-completion/completions/%{name}
#For alternatives
mv %{buildroot}%{_bindir}/mt %{buildroot}%{_bindir}/mtst
mv %{buildroot}%{_mandir}/man1/mt.1 %{buildroot}%{_mandir}/man1/mtst.1
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/mt %{buildroot}%{_bindir}/mt
ln -s -f %{_sysconfdir}/alternatives/mt.1%{ext_man} %{buildroot}%{_mandir}/man1/mt.1%{ext_man}

%post
%{_sbindir}/update-alternatives --force \
    --install %{_bindir}/mt mt %{_bindir}/mtst 30 \
    --slave %{_mandir}/man1/mt.1%{ext_man}  mt.1%{ext_man}  %{_mandir}/man1/mtst.1%{ext_man}
%udev_rules_update

%postun
if [ "$1" = 0 ] ; then
   "%{_sbindir}/update-alternatives" --remove mt %{_bindir}/mtst
fi
%udev_rules_update

%files
%license COPYING
%doc README.md CHANGELOG.md stinit.def.examples
%ghost %{_bindir}/mt
%{_bindir}/mtst
%{_sbindir}/stinit
%ghost %{_mandir}/man1/mt.1%{ext_man}
%{_mandir}/man1/mtst.1%{?ext_man}
%{_mandir}/man8/stinit.8%{?ext_man}
%config(noreplace) %{_sysconfdir}/stinit.def
%{_udevrulesdir}/61-storage-tape-init.rules
%ghost %{_sysconfdir}/alternatives/mt
%ghost %{_sysconfdir}/alternatives/mt.1%{ext_man}
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Wed May 17 2023 Alexey Svistunov <svalx@svalx.net>
- Update to version 1.7:
  * fixes a single bug in stinit parsing of invalid definitions
  * add IBM 3590 B/E format to tape densities table (Chris Dinneen)
- Cleanup secfile
* Wed Nov 25 2020 Kristyna Streitova <kstreitova@suse.com>
- Fix Source URL
* Sun Nov 22 2020 svalx@svalx.net
- Update to version 1.4:
  * show default tape device in usage output (Iustin Pop)
  * improve parsing of the stinit.def configuration file to detect and flag some of the possible errors,
    and add tests to prevent regressions (Iustin Pop)
  * add LTO-8 (hrchu) and LTO-7 formatted as M8 (Iustin Pop) density codes
  * internal code improvements for issues flagged by Coverity scan warnings (Gris Ge)
  * add bash auto-completion file (Paweł Marciniak)
  * don't strip anymore binaries on installation, as nowadays this is the job of package managers (Dan Horák)
- Cleanup with spec-cleaner
* Fri Mar 17 2017 svalx@svalx.net
- Switch binaries to alternatives system
- Change package description
* Thu Mar 16 2017 mpluskal@suse.com
- Cleanup with spec-cleaner
- Refresh udev rules via scriplets
* Sun Aug  7 2016 olaf@aepfle.de
- Provide/Obsolete mt_st
* Wed Jun 29 2016 svalx@svalx.net
- Update to version 1.3:
  * add more density codes (Kai Mäkisara)
  * check for overflow when using k, M or G suffixes (Kai Mäkisara)
  * allow negative argument for mkpartition, supported by Linux 4.6
    and later (Kai Mäkisara)
  * fix compilation with musl libc (Felix Janda)
  * allow configuring the default tape device and installation
    paths (e.g. /bin vs. /usr/bin) at build/install time (Iustin
    Pop)
  * code cleanups from the SUSE package (Alexey Svistunov)
  * update the supplied example file (Alexey Svistunov)
  * fix config file parsing bug in stinit (Iustin Pop)
- Add keyring file
- Removed all patches - fixed upstream
- Using DEFTAPE and EXEC_PREFIX variables in specfile
- Merged Martin Pluskal changes from devel package
* Thu Mar 10 2016 svalx@svalx.net
- Add Provides/Obsoletes tags to specfile
* Thu Mar  3 2016 svalx@svalx.net
- Remove rename-mt-to-mtst.patch, 'mt' binary name is no longer conflicts with cpio
- Add mt-default-device.patch -- change mt default device from /dev/tape to /dev/nst0
- Specfile cleanup
- Rename package to canonical name 'mt-st'
* Thu Feb 25 2016 svalx@svalx.net
- Update to version 1.2
  * many updates to density codes (SDLT, LTO 5,6 and 7, etc.) (various people)
  * multiple man page updates (various people)
  * improve default tape device handling in mt: check that it actually is a character device,
    in order to show better error messages when /dev/tape is a different type (e.g. directory when using udev)
  * small bug fix in stinit in parsing the input file (David Binderman)
  * improve build system by allowing easier customisation of build flags and installation directory
    (via DESTDIR, not prefix) and by sanitising the creation of the dist archive (Iustin Pop)
  * sanitise the source code to get rid of GCC warnings (Jan Christoph Nordholz, Iustin Pop)
  * add stshowoptions alias to stshowopt (Ivo De Decker)
  * expand the provided stinit.def.examples file (Suggested by Ralf-Peter Rohbeck)
  * improve the --help output of stinit (Dan Horák)
  * change of maintainership to Iustin Pop iustin@k1024.org
- Split mt-st-1.1.patch on to change-path-to-binary.patch, fix-mans-install.patch and rename-mt-to-mtst.patch,
  improve Makefile flexible
- Rebase mt-st-codecleanup.patch
- Add default template stinit.def configuration file
- Add %%{?_smp_mflags} for build
- Change URL and Source paths in specfile to recent
- Add udev rule for stinit
- Add gpg signature of source tarball
- Add Ultrium LTO-3 definitions to examples
- Clean specfile by spec-cleaner utility
* Fri Nov 11 2011 tbehrens@suse.com
- Update to version 1.1
  * unused defines removed from mtio.h (compiles also with distributions no
    having linux/qic117.h)
  * add support for MT_ST_SILI to mt and stinit
  * add command showoptions for kernels >= 2.6.26
- removed obsolete mt-st-0.9b-local_qic117_h.patch (changes are
  upstream)
- updated mt-st-0.9b.patch to mt-st-1.1.patch
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Wed Mar 14 2007 pth@suse.de
- Update to 0.9b:
  Changes since 0.7:
  - add local copy of qic117.h missing from recent kernels.
  - only stinit changed
  - more density codes
  - put man page into /usr/share/man/man1
  - documentation cleanup
  - add some density translations
  - counts can use the k, M, or G postfix
* Sat Nov 11 2006 olh@suse.de
- fix doc file permission
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Tue Nov 27 2001 garloff@suse.de
- Use %%attr and remove -m -o -g from install to allow building
  as non-root.
* Tue Nov 27 2001 garloff@suse.de
- Update to mt-st-0.7:
  * eject alias for rewoffl (GNU mt compat)
  * some new density codes
  * cleaning status and request handling
* Fri Dec  1 2000 garloff@suse.de
- Update to mt-st-0.6; including osst (OnStream) support.
* Fri May 26 2000 garloff@suse.de
- Add some docu
- Use BuildRoot.
* Sat Feb  5 2000 garloff@suse.de
- Move manpages to /usr/share/man
* Tue Jan  4 2000 garloff@suse.de
- upgrade to 0.5b (including stinit).
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
